@@ -3,12 +3,15 @@
 
 #include "defines.h"
 #include "random.h"
-#include <math.h>
+//#include <math.h>
+
+#include <R.h>
+#include <Rmath.h>
 
 double sumProd( double *a, double *b, int N );
 
 extern "C" {
-  void fbati( double *pRes, // the result
+  void fbati_cpp( double *pRes, // the result
 
               int *pN,   // the length of the upcoming vectors
               double *xmxbar,  // all of these vectors are sorted by group
